==> qt-creator-opensource-src-3.5.1.tar.gz: qt-creator-opensource-src-3.5.1/share/qtcreator/qml/qmlpuppet/commands/changeauxiliarycommand.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "changeauxiliarycommand.h"

#include <QDebug>

namespace QmlDesigner {

ChangeAuxiliaryCommand::ChangeAuxiliaryCommand()
{
}

ChangeAuxiliaryCommand::ChangeAuxiliaryCommand(const QVector<PropertyValueContainer> &auxiliaryChangeVector)
    : m_auxiliaryChangeVector (auxiliaryChangeVector)
{
}

QVector<PropertyValueContainer> ChangeAuxiliaryCommand::auxiliaryChanges() const
{
    return m_auxiliaryChangeVector;
}

QDataStream &operator<<(QDataStream &out, const ChangeAuxiliaryCommand &command)
{
    out << command.auxiliaryChanges();

    return out;
}

QDataStream &operator>>(QDataStream &in, ChangeAuxiliaryCommand &command)
{
    in >> command.m_auxiliaryChangeVector;

    return in;
}

QDebug operator <<(QDebug debug, const ChangeAuxiliaryCommand &command)
{
    return debug.nospace() << "ChangeAuxiliaryCommand(auxiliaryChanges: " << command.m_auxiliaryChangeVector << ")";
}

} // namespace QmlDesigner

==> qt-creator-opensource-src-4.12.0.tar.gz: qt-creator-opensource-src-4.12.0/share/qtcreator/qml/qmlpuppet/commands/changeauxiliarycommand.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "changeauxiliarycommand.h"

#include <QDebug>

namespace QmlDesigner {

ChangeAuxiliaryCommand::ChangeAuxiliaryCommand() = default;

ChangeAuxiliaryCommand::ChangeAuxiliaryCommand(const QVector<PropertyValueContainer> &auxiliaryChangeVector)
    : m_auxiliaryChangeVector (auxiliaryChangeVector)
{
}

QVector<PropertyValueContainer> ChangeAuxiliaryCommand::auxiliaryChanges() const
{
    return m_auxiliaryChangeVector;
}

QDataStream &operator<<(QDataStream &out, const ChangeAuxiliaryCommand &command)
{
    out << command.auxiliaryChanges();

    return out;
}

QDataStream &operator>>(QDataStream &in, ChangeAuxiliaryCommand &command)
{
    in >> command.m_auxiliaryChangeVector;

    return in;
}

QDebug operator <<(QDebug debug, const ChangeAuxiliaryCommand &command)
{
    return debug.nospace() << "ChangeAuxiliaryCommand(auxiliaryChanges: " << command.m_auxiliaryChangeVector << ")";
}

} // namespace QmlDesigner
